==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fhancock0.9.tar.gz: hancock/hancock.php <==
<?php

   /**
    **  hancock.php
    **
    **/

   chdir('..');

   include_once('../src/validate.php');
   include_once('../functions/page_header.php');
   include_once('../functions/display_messages.php');
   include_once('../functions/prefs.php');
   include_once('../src/load_prefs.php');

   global $username, $data_dir, $_POST, $_FILES;
   // Set up the page
   displayPageHeader($color, 'None');

echo "  <br>
  <table width=\"95%\" align=\"center\" border=\"0\" cellpadding=\"2\">
    <tr>
      <td bgcolor=\"";
echo "$color[0]";
	echo "\">
        <center><b>john hancock signature randomizer</b></center>
      </td>
    </tr>
  </table>";

   // Deal with the submitted form
   if ($_POST['submit_hancock'] && 
       is_uploaded_file($_FILES['fname']['tmp_name']) &&
       is_readable($_FILES['fname']['tmp_name'])) {

      // Open the imported file for read
      $file = file($_FILES['fname']['tmp_name']);
	
	/*
	echo "raw uploaded: " . "<P>";
		
	for ($l=0; $l < count($file); $l++) {
		echo ":" . $file[$l] . ":" . "<br>";
	}
	*/
	
	//----- Explode on newlines	
    for ($l=0; $l < count($file); $l++) {
		$line = explode("\r\n", rtrim($file[$l]));
		array_splice($file, $l, 1, $line);
	}
	
	//----- print the splice results
	/*
	echo "after splice: " . "<P>";
	for ($l=0; $l < count($file); $l++) {
		echo ":" . $file[$l] . ":" . "<br>";
	}
	*/

    //------ stitch it back together
    $sigstring = implode("!@#$%", $file);
    //$sigstring = preg_replace("/(\015)/", "-015-", $sigstring);
    //$sigstring = preg_replace("/(\012)/", "-012-", $sigstring);
	//$sigstring = preg_replace("/(\015\012)|(\015)|(\012)/","<br />",$sigstring);

	setPref($data_dir, $username, 'hancock_signatures', $sigstring);
	//echo "You uploaded:<P> " . $sigstring . "<P>";
	$sigArray = explode("!@#$%--!@#$%", $sigstring);
    echo "<center>" . count($sigArray) . " signatures imported.</center>\n";
}
    $jhheader = $_POST['jhheader'] ;
    setPref($data_dir, $username, 'hancock_header', $jhheader);
    $jhfooter = $_POST['jhfooter'] ;
    setPref($data_dir, $username, 'hancock_footer', $jhfooter);
	if (isSet($_POST['activate'])) {
		setPref($data_dir, $username, 'hancock_enabled', $_POST['activate']);
	} else {
		setPref($data_dir, $username, 'hancock_enabled', '');
	}
      
   echo "Return to the <a href=\"../../src/options.php\">Options</a> page.\n";
?>
 </body></html>

==> countdl.php?fileurl=http%3A%2F%2Fwww.squirrelmail.org%2Fplugins%2Fhancock-1.4-0.9.tar.gz: hancock/hancock.php <==
<?php

   /**
    **  hancock.php
    **
    **/
/*
   chdir('..');

   include_once('../src/validate.php');
   include_once('../functions/page_header.php');
   include_once('../functions/display_messages.php');
   include_once('../functions/prefs.php');
   include_once('../src/load_prefs.php');
*/
define('SM_PATH','../../');

/* SquirrelMail required files. */
require_once(SM_PATH . 'include/validate.php');
require_once(SM_PATH . 'functions/page_header.php');
require_once(SM_PATH . 'functions/imap.php');
require_once(SM_PATH . 'include/load_prefs.php');

   global $username, $data_dir, $_POST, $_FILES;
   // Set up the page
   displayPageHeader($color, 'None');

echo "  <br>
  <table width=\"95%\" align=\"center\" border=\"0\" cellpadding=\"2\">
    <tr>
      <td bgcolor=\"";
echo "$color[0]";
	echo "\">
        <center><b>john hancock signature randomizer</b></center>
      </td>
    </tr>
  </table>";

   // Deal with the submitted form
   if ($_POST['submit_hancock'] && 
       is_uploaded_file($_FILES['fname']['tmp_name']) &&
       is_readable($_FILES['fname']['tmp_name'])) {

      // Open the imported file for read
      $file = file($_FILES['fname']['tmp_name']);
	
	/*
	echo "raw uploaded: " . "<P>";
		
	for ($l=0; $l < count($file); $l++) {
		echo ":" . $file[$l] . ":" . "<br>";
	}
	*/
	
	//----- Explode on newlines	
    for ($l=0; $l < count($file); $l++) {
		$line = explode("\r\n", rtrim($file[$l]));
		array_splice($file, $l, 1, $line);
	}
	
	//----- print the splice results
	/*
	echo "after splice: " . "<P>";
	for ($l=0; $l < count($file); $l++) {
		echo ":" . $file[$l] . ":" . "<br>";
	}
	*/

    //------ stitch it back together
    $sigstring = implode("!@#$%", $file);
    //$sigstring = preg_replace("/(\015)/", "-015-", $sigstring);
    //$sigstring = preg_replace("/(\012)/", "-012-", $sigstring);
	//$sigstring = preg_replace("/(\015\012)|(\015)|(\012)/","<br />",$sigstring);

	setPref($data_dir, $username, 'hancock_signatures', $sigstring);
	//echo "You uploaded:<P> " . $sigstring . "<P>";
	$sigArray = explode("!@#$%--!@#$%", $sigstring);
    echo "<center>" . count($sigArray) . " signatures imported.</center>\n";
}
    $jhheader = $_POST['jhheader'] ;
    setPref($data_dir, $username, 'hancock_header', $jhheader);
    $jhfooter = $_POST['jhfooter'] ;
    setPref($data_dir, $username, 'hancock_footer', $jhfooter);
	if (isSet($_POST['activate'])) {
		setPref($data_dir, $username, 'hancock_enabled', $_POST['activate']);
	} else {
		setPref($data_dir, $username, 'hancock_enabled', '');
	}
      
   echo "Return to the <a href=\"../../src/options.php\">Options</a> page.\n";
?>
 </body></html>
